// (c) Copyright 2011-2012 Cloudera, Inc. All rights reserved.
define([], function() {

/**
 * Creates an invisible scroller so the visible time range is stretched
 * out, showing the requested range in full.
 */
return Class.extend({

	init: function() {
	},

	initialize: function(chartSet) {
		// add a dataSet and a dataProvider for the scroller.
		var dataSet = chartSet.createDataSet(this.getDataSetId());
		var dataProvider = {
			'id': this.getDataProviderId(),
			'dataSet': this.getDataSetId(),
			'column': 1
		};
		chartSet.addEntry(chartSet.getDataSets(), dataSet);
		chartSet.addEntry(chartSet.getScrollerDataProviders(), dataProvider);
	},

	/**
	 * Renders an invisible scroller.
	 */
	createScroller: function() {
		// To debug, set the height to 40, otherwise it will be hidden.
		//
		// The value in the scroller is 1 (see setRange).
		//
		// Normally, the scroller below the main charts is invisible,
		// so it doesn't matter whether it is 1 or 0.
		//
		// the min/max values are only applicable for debugging only.
		// Setting the min = 0, max = 2, so we can see what
		// range is stretched/covered.
		var result = {
			'height': 0,
			'enabled': true,
			'dataProvider': this.getDataProviderId(),
			'connectMissingPoints': true,
			'minimumMode': 'CustomValue',
			'minimum': 0,
			'maximumMode': 'CustomValue',
			'maximum': 2,
			'rangeMarkers': {
				'enabled': false,
				'showAlways': false
			},
			'timeScale': {
				'maxTicksCount': 0,
				'labels': {
					'position':'top',
					'font': {
						'color': '#FFFFFF'
					}
				}
			},
			'gridLine': {
				'enabled': false
			},
			'border': {
				'enabled': false
			}
		};
		return result;
	},

	getDataSetId: function() {
		return "chartStretcher";
	},

	getDataProviderId: function() {
		return "chartStretcherProvider";
	},

	setRange: function(chartSet, range) {
		try {
			var csvData = range.startDate.getTime() + ",1\n" +
				range.endDate.getTime() + ",1\n";
			chartSet.chart.appendData(this.getDataSetId(), csvData);
		} catch (ex) {
			console.log(ex);
		}
	}
});

});
