// (c) Copyright 2012 Cloudera, Inc. All rights reserved.
define([
			 "cloudera/chart/TimeBrowserURLUpdater",
			 "cloudera/chart/TimeBrowserServerState",
			 "cloudera/chart/TimeBrowserState"
], function(TimeBrowserURLUpdater, TimeBrowserServerState, TimeBrowserState) {

	describe("TimeBrowserURLUpdater Tests", function() {
		var state, updater;

		beforeEach(function() {
			var options = {
				isCurrentMode : false,
				firstVisibleDate : new Date(1),
				lastVisibleDate : new Date(10),
				markerDate : new Date(5),
				firstDate : new Date(1),
				lastDate : new Date(20)
			};
			state = new TimeBrowserState(options);
			updater = new TimeBrowserURLUpdater({}, state);
		});

		it("should calculate the new URL Params.", function() {
			var hash = "";
			var serverState = new TimeBrowserServerState(state);
			var newHash = updater.toURLParams(serverState, hash);
			expect(newHash).toEqual("currentMode=false&startTime=1&endTime=10&markerTime=5&firstTime=1&lastTime=20");
		});

		it("should calculate the new URL Params while preserving/overriding existing parameters.", function() {
			var hash = "currentMode=true&foo=bar";
			state.lastDate = new Date(30);
			var serverState = new TimeBrowserServerState(state);
			var newHash = updater.toURLParams(serverState, hash);
			expect(newHash).toEqual("currentMode=false&foo=bar&startTime=1&endTime=10&markerTime=5&firstTime=1&lastTime=30");
		});

		// This test is flaky: it fails with different actual values per test
		// run. andyao and drhayes spent some time trying to run down the cause
		// but couldn't find it. Event subscription in zombie closures hanging
		// around in _.defer blocks is the leading candidate.
		// Be afraid. Be very afraid.
		xit("should update itself with values from the URL Params.",function() {
			var urlParams;

			urlParams = "currentMode=false&startTime=1&endTime=10&markerTime=5&firstTime=1&lastTime=20";
			updater.updateFromURLParams(urlParams);
			expect(state.firstVisibleDate.getTime()).toEqual(1);
			expect(state.lastVisibleDate.getTime()).toEqual(10);
			expect(state.markerDate.getTime()).toEqual(5);
			expect(state.firstDate.getTime()).toEqual(1);
			expect(state.lastDate.getTime()).toEqual(20);
			expect(state.isCurrentMode).toEqual(false);

			urlParams = "currentMode=false&startTime=100&endTime=200&markerTime=150&firstTime=20&lastTime=300";
			updater.updateFromURLParams(urlParams);
			expect(state.firstDate.getTime()).toEqual(20);
			expect(state.lastDate.getTime()).toEqual(300);
			expect(state.isCurrentMode).toEqual(false);

			urlParams = "currentMode=false&startTime=100&endTime=200&markerTime=150&firstTime=20&lastTime=300";
			updater.updateFromURLParams(urlParams);
			expect(state.firstVisibleDate.getTime()).toEqual(100);
			expect(state.isCurrentMode).toEqual(false);

			urlParams = "currentMode=true&startTime=100&endTime=200&markerTime=150&firstTime=20&lastTime=300";
			updater.updateFromURLParams(urlParams);
			expect(state.firstVisibleDate.getTime()).toEqual(100);
			expect(state.isCurrentMode).toEqual(true);

		});
	});
});
