// Copyright (c) 2011-2012 Cloudera, Inc.  All rights reserved.
define([
	"cloudera/Util",
	"cloudera/common/Humanize",
	"cloudera/Analytics"
], function(Util, Humanize, analytics) {

return function(params) {

	var _startTime = params.startTime;
	var _endTime = params.endTime;
	var _modalId = "#" + params.modalId;

	var $fromTime = $(_modalId + ' input[name="fromTime"]');
	var $toTime = $(_modalId + ' input[name="toTime"]');
	var $fromTimestamp = $(_modalId + ' input[name="fromTimestamp"]');
	var $toTimestamp = $(_modalId + ' input[name="toTimestamp"]');

	var onSubmitForm = function(e) {
		// date in server timezone.
		var serverFromDate = $fromTime.datetimepicker('getDate');
		var serverToDate = $toTime.datetimepicker('getDate');

		// date in local timezone.
		var fromDate = Humanize.fromServerDate(serverFromDate);
		var toDate = Humanize.fromServerDate(serverToDate);

		if (!fromDate || !toDate) {
			handleError(params.missingTimestampError);
			return false;
		}

		// Timestamp is UTC, so must be sent using the local timezone.
		var fromTimestampVal = fromDate.getTime();
		var toTimestampVal = toDate.getTime();

		if (fromTimestampVal > toTimestampVal) {
			handleError(params.invalidTimestampError);
			return false;
		}

		$fromTimestamp.val(fromTimestampVal);
		$toTimestamp.val(toTimestampVal);
		analytics.trackEvent('Support', 'Diagnostics Data Sent');
		$(_modalId).modal("hide");
	};

	var handleError = function(message) {
		$fromTime.parents(".control-group").addClass("error");
		$toTime.parents(".control-group").addClass("error");
		$toTime.siblings(".help-block").html(message);
	};

	$fromTime.datetimepicker();
	$toTime.datetimepicker();

	// Display using server timezone.
	$fromTime.datetimepicker('setDate', Humanize.toServerDate(new Date(_startTime)));
	$toTime.datetimepicker('setDate', Humanize.toServerDate(new Date(_endTime)));

	$('.sendDiagnosticsButton').click(onSubmitForm);
};
});
